REngine

Struct REngine 

pub struct REngine;
Handle to an initialized R runtime.

This is a marker type indicating R has been initialized for this process. R cleanup (via Rf_endEmbeddedR) is intentionally NOT called because it performs non-reentrant operations that can crash if called during Drop or concurrent with other cleanup. The OS reclaims all resources on process exit.

Implementations

Source

impl REngine

pub fn build() -> REngineBuilder

Create a new builder for configuring R initialization.

pub unsafe fn process_events(&self)

Process pending R events.

Call this periodically to allow R to handle events, especially when running a long computation.

Safety

Must be called from the thread that initialized R.

pub unsafe fn check_interrupt(&self)

Check for user interrupts (Ctrl+C).

Safety

Must be called from the thread that initialized R.