pub struct REngine;Expand description
Handle to an initialized R runtime.
This is a marker type indicating R has been initialized for this process.
R cleanup (via Rf_endEmbeddedR) is intentionally NOT called because it
performs non-reentrant operations that can crash if called during Drop
or concurrent with other cleanup. The OS reclaims all resources on process exit.
Implementations
Sourceimpl REngine
impl REngine
Sourcepub fn build() -> REngineBuilder
pub fn build() -> REngineBuilder
Create a new builder for configuring R initialization.
Sourcepub unsafe fn process_events(&self)
pub unsafe fn process_events(&self)
Process pending R events.
Call this periodically to allow R to handle events, especially when running a long computation.
Safety
Must be called from the thread that initialized R.
Sourcepub unsafe fn check_interrupt(&self)
pub unsafe fn check_interrupt(&self)